Blob class abstract

Annotations
  • @JS.new('Blob')
  • @anonymous

Constructors

Blob()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isEqual(Object other) → bool
Returns true if this Blob is equal to the provided other.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBase64() → String
toString() → String
A string representation of this object.
inherited
toUint8Array() → Uint8List

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromBase64String(String base64) → Blob
fromUint8Array(Uint8List list) → Blob